==> filter-update-2.9.0.tgz: package/README.md <==
Keeps values which pass a test. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [filter], [filter$].<br>
> Similar: [map], [filter], [reduce], [accumulate].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.filter$(x, fn, [ths]);
// x:   an array (updated)
// fn:  test function (v, i, x)
// ths: this argument
// --> x
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 4, 5];
array.filter$(x, v => v % 2 === 1);
// [ 1, 3, 5 ]

x;
// [ 1, 3, 5 ]

var x = [1, 2, 3, 4, 5];
array.filter$(x, v => v % 2 === 0);
// [ 2, 4 ]
```

### references

- [Data.List.filter: Haskell](https://hackage.haskell.org/package/base-4.12.0.0/docs/Data-List.html#v:filter)
- [Array.prototype.filter: MDN web docs](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/filter)
- [array_filter: PHP](https://www.php.net/manual/en/function.array-filter.php)
- [_.remove: lodash](https://lodash.com/docs/4.17.15#remove)
- [_.without: lodash](https://lodash.com/docs/4.17.15#without)
- [_.compact: lodash](https://lodash.com/docs/4.17.15#compact)
- [_.pull: lodash](https://lodash.com/docs/4.17.15#pull)
- [_.pullAll: lodash](https://lodash.com/docs/4.17.15#pullAll)
- [_.pullAllBy: lodash](https://lodash.com/docs/4.17.15#pullAllBy)
- [_.pullAllWith: lodash](https://lodash.com/docs/4.17.15#pullAllWith)
- [Array.filter: sugarjs](https://sugarjs.com/docs/#/Array/filter)
- [Array.exclude: sugarjs](https://sugarjs.com/docs/#/Array/exclude)
- [Array.compact: sugarjs](https://sugarjs.com/docs/#/Array/compact)
- [array-tools.where: @75lb](https://www.npmjs.com/package/array-tools)

[:running:]: https://npm.runkit.com/@extra-array/filter-update
[:package:]: https://www.npmjs.com/package/@extra-array/filter-update
[:moon:]: https://www.npmjs.com/package/@extra-array/filter-update.min
[:ledger:]: https://unpkg.com/@extra-array/filter-update/
[filter]: https://github.com/nodef/extra-array/wiki/filter
[filter$]: https://github.com/nodef/extra-array/wiki/filter$
[map]: https://github.com/nodef/extra-array/wiki/map
[reduce]: https://github.com/nodef/extra-array/wiki/reduce
[accumulate]: https://github.com/nodef/extra-array/wiki/accumulate
[:vhs:]: https://asciinema.org/a/332045

==> filter-update-2.9.26.tgz: package/README.md <==
Keeps values which pass a test. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [filter], [filter$].<br>
> Similar: [map], [filter], [reduce], [accumulate].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.filter$(x, fn);
// x:  an array (updated)
// fn: test function (v, i, x)
// --> x
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 4, 5];
array.filter$(x, v => v % 2 === 1);
// [ 1, 3, 5 ]

x;
// [ 1, 3, 5 ]

var x = [1, 2, 3, 4, 5];
array.filter$(x, v => v % 2 === 0);
// [ 2, 4 ]
```

### references

- [Data.List.filter: Haskell](https://hackage.haskell.org/package/base-4.12.0.0/docs/Data-List.html#v:filter)
- [Array.prototype.filter: MDN web docs](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/filter)
- [array_filter: PHP](https://www.php.net/manual/en/function.array-filter.php)
- [_.remove: lodash](https://lodash.com/docs/4.17.15#remove)
- [_.without: lodash](https://lodash.com/docs/4.17.15#without)
- [_.compact: lodash](https://lodash.com/docs/4.17.15#compact)
- [_.pull: lodash](https://lodash.com/docs/4.17.15#pull)
- [_.pullAll: lodash](https://lodash.com/docs/4.17.15#pullAll)
- [_.pullAllBy: lodash](https://lodash.com/docs/4.17.15#pullAllBy)
- [_.pullAllWith: lodash](https://lodash.com/docs/4.17.15#pullAllWith)
- [Array.filter: sugarjs](https://sugarjs.com/docs/#/Array/filter)
- [Array.exclude: sugarjs](https://sugarjs.com/docs/#/Array/exclude)
- [Array.compact: sugarjs](https://sugarjs.com/docs/#/Array/compact)
- [array-tools.where: @75lb](https://www.npmjs.com/package/array-tools)

[:running:]: https://npm.runkit.com/@extra-array/filter-update
[:package:]: https://www.npmjs.com/package/@extra-array/filter-update
[:moon:]: https://www.npmjs.com/package/@extra-array/filter-update.min
[:ledger:]: https://unpkg.com/@extra-array/filter-update/
[filter]: https://github.com/nodef/extra-array/wiki/filter
[filter$]: https://github.com/nodef/extra-array/wiki/filter$
[map]: https://github.com/nodef/extra-array/wiki/map
[reduce]: https://github.com/nodef/extra-array/wiki/reduce
[accumulate]: https://github.com/nodef/extra-array/wiki/accumulate
[:vhs:]: https://asciinema.org/a/332045
